==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/Input/opus/translations/opus_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="49"/>
        <source>Opus Plugin</source>
        <translation>תוסף Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="52"/>
        <source>Ogg Opus Files</source>
        <translation>תוסף Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="126"/>
        <source>About Opus Audio Plugin</source>
        <translation>אודות תוסף שמע Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="127"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>תוסף שמע Opus של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="128"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>חובר על ידי: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;‎</translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/Input/opus/translations/opus_plugin_he.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="he">
<context>
    <name>DecoderOpusFactory</name>
    <message>
        <location filename="../decoderopusfactory.cpp" line="44"/>
        <source>Opus Plugin</source>
        <translation>תוסף Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="47"/>
        <source>Ogg Opus Files</source>
        <translation>תוסף Ogg Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="121"/>
        <source>About Opus Audio Plugin</source>
        <translation>אודות תוסף שמע Opus</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="122"/>
        <source>Qmmp Opus Audio Plugin</source>
        <translation>תוסף שמע Opus של Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderopusfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpusMetaDataModel</name>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="55"/>
        <source>Length</source>
        <translation>אריכות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Sample rate</source>
        <translation>שיעור דגימה</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="56"/>
        <source>Hz</source>
        <translation>הרץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="57"/>
        <source>Channels</source>
        <translation>ערוצים</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>Bitrate</source>
        <translation>שיעור סיביות</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="58"/>
        <source>kbps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>File size</source>
        <translation>גודל קובץ</translation>
    </message>
    <message>
        <location filename="../opusmetadatamodel.cpp" line="59"/>
        <source>KB</source>
        <translation>ק״ב</translation>
    </message>
</context>
</TS>
